def greeting(headers: dict):
    """
    This function returns a personalized greeting message
    based on the 'Name' header passed in the dictionary.

    :param headers: Dictionary containing the header information.
    :return: Greeting message based on the 'Name' key.
    """
    name = headers.get('Name', None)
    if name:
        return f"Hello {name}! nice to meet you"
    else:
        return "No name provided inside header"



from setuptools import setup, find_packages
# python setup.py sdist bdist_wheel
# twine upload dist/*

setup(
    name='abhinav_greeting',
    version='0.4',
    packages=find_packages(),
    description='A simple Python package that provides personalized greetings.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Abhinav Gera',
    author_email='abhinav.gera@aligne.ai',
    url='https://github.com/abhinav-aligne/abhinav_greeting',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)
